##########################################################
#		R SCRIPT PHENOTYPIC PLASTICITY
#		     ENVIRONMENTAL QUALITY
#
##########################################################

##########################################################
#	CHANGE NAME OF FACTORS
##########################################################

#rename problematic factors

# how.plasticity.
levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"random-noise\"" ] <- "random-noise"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"standard-model\""] <- "standard-model"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == 
"\"adaptive-sinusoidal\""] <- "adaptive-sinusoidal"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"adaptive-logistic\""] <- "adaptive-logistic"

##########################################################
#	CHECK LENGTH OF ARRAY
##########################################################

# check length of the array. It should match the number of replicates
length(myData$N[myData$density.dependence.effect == 1.8 & 
myData$level.autocorr == 0 & 
myData$rate.change.of.optimum == 0.01 &
myData$std.of.k == 10 & 
myData$slope == 1 &
#myData$beneficial.mutations == 0.5 &
#myData$k.capacity == 1000 &
#myData$X.step. == 1 &
myData$mut.rate.per.locus == 0.0001 &
myData$how.plasticity. == "standard-model"])



##########################################################
#	BARPLOT
##########################################################

mrate <- 1e-03
slope <- 1
r <- 0
p <- c("standard-model", "random-noise",
				  "adaptive-sinusoidal", "adaptive-logistic",
				  "linear-RN")

# initialization
x = matrix(0L, nrow = 2, ncol = 3)

# y stores error
y = matrix(0L, nrow = 2, ncol = 3)

# number of observations
obs <- 100

i = 1
j = 1

for(k in c(10, 20))
{
	for(d in c(0.5, 1.8, 2.5))
	{

		condition <- myData$density.dependence.effect == d & 
				 myData$std.of.k == k & 		 
		 		 myData$level.autocorr == 0 & 
		 		 myData$rate.change.of.optimum == r &
		 		 myData$slope == slope &
		 		 myData$mut.rate.per.locus == mrate &
		 		 myData$how.plasticity. == p[1]

		dummy <- myData$N[condition]

		foo <- length(dummy[dummy > 0 ]) / length(dummy)
		
		# error bars according to binomial distribution
		# proportion of success foo
		# instead of foo = 1, we assume 0.995 of success
		if(foo == 1) { foo = 0.995 }

		x[i,j] <- foo
		success = x[i,j]
		# obs observations (see above)
		y[i,j] = sqrt(success * (1 - success) / obs)

		j = j + 1

	}
	j = 1
	i = i + 1
}

x <- t(x)
y <- t(y)

######### PLOT ##################

foo <- barplot(x, beside = TRUE, las = 1, width = 0.1, space = c(0.1, 1),
	  ylim = c(0,1.05),
	  ylab = "probability of persistence",
	  #xlab = expression(paste("Scenario of density dependence effect ", 
	#	   psi)),
	  main = "Persistence per life history strategy and scenario of stochastic K",
	  cex.lab = 1.5, cex.axis = 1.2, cex.names = 1.2,	  
	  names.arg = c("sd = 0.1K", "sd = 0.2K"),
	  col = c("white", "grey93", "grey33"),
        legend = c(expression(paste(psi, " = ", 0.5)),
			 expression(paste(psi, " = ", 1.8)),
			 expression(paste(psi, " = ", 2.5)))
	  )

# add error bars

arrows(x0 = foo, y0 = x - y 
	,x1 = foo, y1 = x + y
	,code = 3, angle = 90, length = 0.05)

