
# MODELING DIFFERENT TYPES OF PHENOTYPIC PLASTICITY
# Random PP, Linear RN, Sinusoidal and logistic

# set the environmental change
theta <- seq(from = 0, to = 5, by = 0.02)

# genetic component
a <- 0

rnd <- rep(0, length(theta))
line <- rep(0, length(theta))
slope <- 0.5
sin <- rep(0, length(theta))
log <- rep(0, length(theta))

for (i in 1:length(theta))
{
	# Random PP
	rnd[i] <- a + rnorm(1, 0, 1)

	# linear RN
	line[i] <- a + slope * theta[i]

	# Sinusoidal
	delta <- theta[i] - a
	alpha <- 0
	if(abs (delta) < pi)
	{ alpha <- sin ( abs (delta))}

	sin[i] <- a + delta * alpha

	# logistic
	if (abs(delta) > pi / 2)
	{
		delta <- pi / 2
		alpha <- sin(abs(delta))
	}
	
	log[i] <- a + alpha * delta

}

# plot to pdf
#pdf(file = "fig3_plasticity_methods.pdf"
#    ,width  = 2
#    ,height = 2
#   )

par(mfrow=c(2,2))
#par(mar=c(0,0,0,0)) # default. Values are: bottom, left, top, and right
par(mar=c(4,5,2,2))
lab = 1.8
ax = 1.3
mn = 1.8


plot(rnd, las = 1 #lwd = 2
,ylim = c(-2,3)
,ylab = "Phenotypic response z", xlab = ""
,main = "random noise"
,cex.lab = lab, cex.axis = ax, cex.main = mn, xaxt = "n")

lines(theta, lwd = 2)

plot(line, las = 1, #lwd = 2,
ylab = "", xlab = "",
main = "linear",
cex.lab = lab, cex.axis = ax, cex.main = mn,xaxt = "n")

lines(theta, lwd = 2)

plot(sin, las = 1 #lwd = 2
,ylim = c(0, 2)
,ylab = "Phenotypic response z", xlab = "Environmental state"
,main = "sinusoidal"
,cex.lab = lab, cex.axis = ax, cex.main = mn, xaxt = "n"
)

axis(1, at = c(0, 50, 100, 150, 200, 250), labels = c(0:5), cex.axis = ax)
lines(theta, lwd = 2)



plot(log, las = 1 #lwd = 2
,ylim = c(0, 2)
,ylab = "", xlab = "Environmental state"
,main = "saturating"
,cex.lab = lab, cex.axis = ax, cex.main = mn, xaxt = "n")

axis(1, at = c(0, 50, 100, 150, 200, 250), labels = c(0:5), cex.axis = ax)
lines(theta, lwd = 2)

# limit logistic
min(which(log == pi / 2))

#limit sinusoidal
min(which(sin[-1] == 0))

#dev.off() # create and close file


