##########################################################
#	GENETIC VARIANCE TIME SERIES
#		MEAN +/- SD
#
##########################################################

# read data
df <- read.csv("data_gv.csv", header = TRUE)

#rename problematic factors

# how.plasticity. as factor
df$how.plasticity. <- as.factor(df$how.plasticity.)

levels(df$how.plasticity.)[levels
(df$how.plasticity.) == "\"linear-RN\"" ] <- "linear (slope == 0.5)"

levels(df$how.plasticity.)[levels
(df$how.plasticity.) == "\"standard-model\""] <- "genetic determinism"

levels(df$how.plasticity.)[levels
(df$how.plasticity.) == 
"\"adaptive-sinusoidal\""] <- "sinusoidal"

levels(df$how.plasticity.)[levels
(df$how.plasticity.) == "\"adaptive-logistic\""] <- "saturating"

levels(df$how.plasticity.)

##########################################################
#+ CHECK LENGHT OF ARRAY
##########################################################

x <- df$GV[df$how.plasticity. == "genetic determinism" & 
     	     df$slope == 1 &
           df$mut.rate.per.locus == 0.001 &
	     df$X.run.number. == 1
	     ]

length(x)

##########################################################
#	COMPUTE MEAN FOR EACH TIME STEP
##########################################################

# define conditions:
plasticity <- levels(df$how.plasticity.)

mR <- 0.001
k <- max(df$X.step.)
time <- seq(from = 1, to = max(df$X.step.), by = 1)

# initialization of vectors avg and sdev
avg = NULL
sdev = NULL

# loop begins
for (j in plasticity)
{
	if ( j == "linear (slope == 0.5)") { slope = 0.5 }
	else { slope = 1 }

	for (i in 1:k)
	{
		# store data for timestep i into a dummy variable
		dummy <- df$GV[df$X.step. == i &
		   	   df$slope == slope &
			   df$mut.rate.per.locus == mR &
			   df$how.plasticity. == j 
			   ]
		# get mean and standard deviation
		avg[i] <- mean(dummy, na.rm = TRUE)
		sdev[i] <- sd(dummy, na.rm = TRUE)
	}
	
	# standard error se = sd / sqrt(n)
	se <- sdev / sqrt(length(sdev))

	# store data in corresponding data.frame

	type <- rep(j, times = length(avg))
	foo <- data.frame(type, avg, time, sdev, se 
				,stringsAsFactors = FALSE)

	if( j == "linear (slope == 0.5)"){ line <- foo }
	else if (j == "genetic determinism"){ gdet <- foo }
	else if (j == "sinusoidal") { sin <- foo }
	else if (j == "saturating" ) { log <- foo }
	else { warning("unrecognized plasticity type") }
	
} # end for loop

df <- rbind(gdet, line, sin, log)

names(df) <- c("type", "y", "x", "sd", "se")

# standard error is the standard deviation divided by the
# square root of the sample size

##########################################################
#	PLOTTING DATA
##########################################################

# SEE RSCRIPT_COMBINED_PLOTS.R (PLOT 2)