#######	 GENETIC ACCOMMODATION		###############

# load libraries
library(stringr) # to work with strings / extract pattern

# define function to get the data from netlogo character 
# vectors as numeric vectors and return them as dataframe
toNumeric <- function(x			# a data frame
			   ,condition	# condition to extract data
			   ,method		# plasticity method (factor level)
			   ,time		# when?, start or end of simulation
			   ,mySlope
			   )
{

	# extract information as number
	# get values (they are characters!)
	genotype  <- df$X.genetic.component..of.turtles[condition]
	phenotype <- df$X.phenotype..of.turtles[condition] 

	# replace empty space with commas
	genotype = gsub(pattern = " ", replacement = ",", x = genotype)
	phenotype = gsub(pattern = " ", replacement = ",", x = phenotype)
	#myvalues = str_remove(myvalues, "[_]")

	# store as numeric into a vector
	genotype <- as.numeric(unlist(str_split(genotype, ",")))
	phenotype <- as.numeric(unlist(str_split(phenotype, ",")))

	# remove NAs created because of the "[]" characters
	genotype <- as.vector(na.omit(genotype))
	phenotype <- as.vector(na.omit(phenotype))
	
	# add columns with important additional information
	type <- rep(method, times = length(genotype))
	when <- rep(time, times = length(genotype))
	slope <- rep(mySlope, times = length(genotype))

	return(data.frame(type, when, slope, genotype, phenotype))
}
############## END OF FUNCTION TONUMERIC			#################


# read data, combine into one dataframe and check its structure
ini <- read.csv("init.csv", header = TRUE)
ini05 <- read.csv("linear05-init.csv", header = TRUE)
end <- read.csv("end.csv", header = TRUE)
end05 <- read.csv("linear05-end.csv", header = TRUE)

#if(endsat != NULL){
#end <- end[end$how.plasticity. != "adaptive-logistic",]
#end <- rbind(end, endsat)
#}

df <- rbind(ini, ini05, end, end05)
str(df)

# DEBUG
# check number of runs. It should match the experimental scenarios
length(df$X.genetic.component..of.turtles)
# define factors
plasticity <- levels(as.factor(df$how.plasticity.))
myTime <- levels(as.factor(df$time.limit))
mySlope <- levels(as.factor(df$slope))

# loop control variable
first_run = TRUE
for (method in plasticity)
{
	for(slope in as.numeric(mySlope))
	{
		if((slope < 1 && method == "linear-RN") ||
		    slope == 1)
		{
			for(time in as.numeric(myTime))
			{
			
				# define condition
				condition = df$slope == slope & 
						df$how.plasticity. == method &
						df$time.limit == time
				#length(df$X.genetic.component..of.turtles[condition])
				
				if(first_run == TRUE)
				{
					data <- toNumeric(df 
								,condition
								,method
								,time
								,slope)
					first_run = FALSE
				
					#DEBUG
					#print("first")
					#print(method)
					#print(time)
					#print(slope)
					#print(length(data$type))
				} else{
					foo <- toNumeric(df 
							     ,condition
							     ,method
							     ,time
							     ,slope)
					data <- rbind(data, foo)

					#DEBUG
					#print("else")
					#print(method)
					#print(time)
					#print(slope)
					#print(length(data$type))

					}
			}
		}
	}
} 

length(data$genotype[data$when == 0 & 
			   data$type == "linear-RN" & 
			   data$slope == 0.5]
	)




## PLOT DATA

# package plotrix: multiple histograms side by side
#install.packages("plotrix")
library(scales) # alpha function for colour transparency
library(plotrix)

par(mfrow = c(4,1))

xtext = ""
custom_palette <- c("darkgray", "black", "white")
legend_position = "center" #"topright"

# value of the optimum
# the first value is centered on zero (see methods)
# the end value depends on the simulation run, because it is stochastic
# get the phenotypic optimum as given by the environment
for (p in plasticity)
{
	opt = df$X.optimum..of.patch.0.0[df$how.plasticity == p]
	cat(p, " ", opt, "\n")
}
df$X.optimum..of.patch.0.0[df$how.plasticity == "linear-RN" &
df$slope == 0.5]	

# plot parameters
lab = 4 # cex.lab

for(p in rev(plasticity)) # note the vector is reversed
{
	for(s in rev(as.numeric(mySlope)))
	{
		# get the optimum
		opt <- df$X.optimum..of.patch.0.0[df$how.plasticity == p &
				  		   	    df$slope == s &
					   	   	    df$time.limit == 250]

		if(p == "linear-RN" && s < 1)
		{
			mtext = "linear (slope = 0.5)"
			xtext = ""
			opt <- 60 + 20*opt #4.7 # rescale optimum
		}
		if(p == "linear-RN" && s == 1)
		{
			mtext = "linear perfect"
			xtext = ""
			opt <- 60 + 20*opt #5.2
		}
		if(p == "adaptive-logistic")
		{
			mtext = "saturating"
			xtext = "genotypic / phenotypic value"
			opt = 60 + 20*opt#7
		}
		if(p == "adaptive-sinusoidal")
		{
			mtext = "sinusoidal"
			xtext = ""
			opt <- 60 + 20*opt#5.3
		}



		if((s < 1 && p == "linear-RN") ||
	          s == 1)
		{

			x1 <- data$genotype[data$type == p & 
			   	  		  data$when == 0 & 
			 	  		  data$slope == s]
			x2 <- data$genotype[data$type == p & 
			 	  		  data$when == 250 & 
			 	  		  data$slope == s]
			y2 <- data$phenotype[data$type == p & 
		     		   		   data$when == 250 & 
			 	   		   data$slope == s]	

			multhist(list(x1, x2, y2)
	   			   ,freq = TRUE# false = probability densities
	   			   ,breaks = seq(-3, 8, by = 0.2)#seq(-2, 6, by = 0.2)
				   ,col = c(custom_palette)
				   ,main = mtext
				   ,xlab = xtext
				   #,xaxt = "n"
	   			  )
			# add phenotypic optimum to the plot
			# the zero of the hist is located at x = 60
			abline(v = 60, lwd = 2, lty = 2
				 ,col = alpha("red", 0.5)
				)
			# the optimum at t = 250 is computed based on its
			# actual value and the equivalence between the axes
			# (see above)
			abline(v = opt, lwd = 2, lty = 2
				 ,col = "red"
				)
			
			if(p == "linear-RN" && s == 1)
			{
				legend(legend_position 
					,legend = c("genotype year = 1", 
						     "genotype year = 250"
						    ,"phenotype year = 250")
					,fill = custom_palette
					,bty = "n" # no border
					)
			}
		}
	}
}

#cex.lab = lab, cex.axis = ax, cex.main = mn, xaxt = "n"

