## Growth rate of the population ##

# carrying capacity K
K <- 500

# define alpha for the three strategies, according to Bj?rklund et al (2009)
alpha <- c (0.5, 1.8, 2.5)

# matrix to store growth rate r for each population size / type of organism
r <- matrix(c(rep(K,0), rep(K,0), rep(K,0)), nrow = K, ncol = length(alpha))

for (i in 1:nrow(r)) # count rows in matrix r; the population size
{
	for(j in 1:ncol(r)) # count columns in r; the strategy
	{
		r[i,j] <- i * exp( alpha[j] * (1 - i / K)) - i
	}
}

myX <- seq(from = 0, to = K, by = 1)

# plot
plot(r[,3], las = 1, type = "l",
lwd = 3, lty = 1, col = "black",
ylab = "N(t+1) - Nt",
xlab = "population size",
main = "Population-level growth rate",
cex.lab = 1.55, cex.axis = 1.30, cex.main = 1.59
)

lines(r[,2], lwd = 3, lty = 2, col = "black")

lines(r[,1], lwd = 3, lty = 2, col = "grey")

#abline(v = K / 2)

# add legend

legend("topright", legend = c(expression(paste(psi, " = ", 0.5)),
expression(paste(psi, " = ", 1.8)),
expression(paste(psi, " = ", 2.5))),
lty = c(2, 2, 1), col = c("grey", "black", "black"), cex = 1.5, lwd = 3)


