
# this function plot the life strategies according to their differences
# in level of density compensation (alpha)
# Here we assume fitness w = 1, and that the only difference among
# the strategies is related to the value of alpha
# the formula is fecundity f = w * e( alpha * (1 - N / K))

# define carrying capacity K
K = 500

# define alpha for the three strategies, according to Bj?rklund et al (2009)
alpha <- c (0.5, 1.8, 2.5)
#alpha2 = 1.8
#alpha3 = 2.5


# create a matrix of dimension alphas * K
fecundity = matrix(c(rep(0, K), rep(0,K), rep(0,K)), nrow= length(alpha), 
ncol = K)

# calculate the value of fecundity for each value of population size N,
# and for each strategy alpha

for(i in 1:nrow(fecundity)) # count rows in the matrix
{
	for (j in 1:ncol(fecundity)) # count columns
	{
		fecundity[i, j] <- 2 * exp( alpha[i] * (1 - j / K))
	}
}
		
# plot random:
plot(fecundity[1,], las = 1, type = "l",
ylim = c(0, 30), 
lwd = 3, lty = 2,
     col = "grey",  
     ylab = "Fecundity (offspring / couple)", xlab = "Population size",
     main = "Expected fecundity per level of density compensation",
     cex.lab = 1.55, cex.axis = 1.55, cex.main = 1.59
     )

lines(fecundity[2,], lwd = 3, lty = 2, col = "black")#"chartreuse4")

lines(fecundity[3,], lwd = 3, lty = 1, col = "black")#"blue")

#lines(fecundity[4,], lwd = 3, lty = 1, col = "black")

#lines(fecundity[5,], lwd = 3, lty = 2, col = "black")

# add legend:
legend("topright", legend = c(expression(paste(psi, " = ", 0.5)),
expression(paste(psi, " = ", 1.8)),
expression(paste(psi, " = ", 2.5))),
#expression(paste(psi, " = ", 1.0)),
#expression(paste(psi, " = ", 1.2))), 
lty = c(2, 2, 1), col = c("grey", "black", "black"), cex = 1.5, lwd = 3)

#text(x = 111, y = 18, label = "Random")

#text(x = 111, y = 17, label = "Gr4_D2")

#text(x = 111, y = 18, label = "Gr4_D3")



